#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/signal.h>
#include <avr/pgmspace.h>
#include <avr/delay.h>

#include "uart.h"


#define XTAL_CPU        7372800      /* 4Mhz */
#define UART_BAUD_RATE    19200      /* 9600 baud */


unsigned char 		rs;


//////////////// Function for transfer on SPI /////////////////////////////
void SPI_sende (unsigned char aData) 
{
	SPDR = aData;										
	while(!(SPSR & (1<<SPIF)));						
}

void writecmd (unsigned char cmd)
{
	unsigned char lower;
	unsigned char upper;
	unsigned char startbyte;
	lower = cmd % 16;
	upper = cmd / 16;
	if (rs != 0)
	{
		startbyte = 0x1F;
		SPI_sende (startbyte);
	
	}
	SPI_sende (lower);
	SPI_sende (upper);
	rs = 0;
	delay_us(50);
}

void writedat (unsigned char dat)
{
	unsigned char lower;
	unsigned char upper;
	unsigned char startbyte;
	lower = dat % 16;
	upper = dat / 16;
	if (rs !=1)
	{
		startbyte = 0x5F;
		SPI_sende (startbyte);
	
	}
	SPI_sende (lower);
	SPI_sende (upper);
	rs = 1;
}

void lcd_init(void)	
{
	delay_ms(10);
	rs = 1;
	writecmd(0x34);
	writecmd(0x09);
	writecmd(0x30);
	writecmd(0x0F);
	delay_ms(3);
	writecmd(0x01);
	delay_ms(3);
	writecmd(0x06);
}

void lcd_chr(unsigned char c)
{
writedat(c);
}

void lcd_str(const char *s)
{
    register unsigned char c;
    while ( (c = *s++) )
    {
     lcd_chr(c);
    }

}/* lcd_str */


int main(void)
{
	DDRB = (1<<DDB3)|(1<<DDB5)|(1<<DDB2);			
	SPCR = (1<<SPE)|(1<<MSTR)|(1<<SPR0)|(1<<DORD);
	uart_init( UART_BAUD_SELECT(UART_BAUD_RATE,XTAL_CPU) ); 
	sei();
	lcd_init();
	lcd_chr("t");

	lcd_str("*");
	lcd_str("testmann");
	for(;;)
	{							//Do-loop
	}
return 0;
}





